@@ -1,7 +1,7 @@
 /*
  * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999-2002, 2011, 2021-2023 Rami Lehti, Pablo Virolainen,
+ * Copyright (C) 1999-2002, 2011, 2021-2025 Rami Lehti, Pablo Virolainen,
  *               Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
@@ -22,14 +22,23 @@
 #ifndef _DB_DISK_H_INCLUDED
 #define _DB_DISK_H_INCLUDED
 
+#include "attributes.h"
 #include "config.h"
+#ifdef HAVE_FSTYPE
+#include "file.h"
+#endif
+#include <sys/stat.h>
 #include <stdbool.h>
-#include "db_config.h"
+
+typedef struct disk_entry {
+    char *filename;
+    struct stat fs;
+#ifdef HAVE_FSTYPE
+    FS_TYPE fs_type;
+#endif
+    int fd;
+    DB_ATTR_TYPE attrs;
+} disk_entry;
 
 void db_scan_disk(bool);
-
-#ifdef WITH_PTHREAD
-int db_disk_start_threads();
-int db_disk_finish_threads();
-#endif
 #endif
