@@ -1,7 +1,7 @@
 /*
  * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 1999-2002, 2006, 2010-2011, 2016, 2019-2023 Rami Lehti,
+ * Copyright (C) 1999-2002, 2006, 2010-2011, 2016, 2019-2025 Rami Lehti,
  *               Pablo Virolainen, Richard van den Berg, Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
@@ -21,18 +21,18 @@
 
 #ifndef _GEN_LIST_H_INCLUDED
 #define _GEN_LIST_H_INCLUDED
-#define PCRE2_CODE_UNIT_WIDTH 8
-#include <pcre2.h>
 #include <stdbool.h>
 #include "attributes.h"
 #include "rx_rule.h"
-#include "seltree_struct.h"
+#include "db_config.h"
+#include "file.h"
+#include "seltree.h"
+#include "db_disk.h"
+
 struct stat;
 
 /* DB_FOO are anded together to form rx_rule's attr */
 
-int compare_node_by_path(const void *n1, const void *n2);
-
 /* 
  * populate_tree()
  * Populate tree with data from disk and db 
@@ -42,19 +42,11 @@ void populate_tree(seltree*);
 
 void write_tree(seltree*);
 
-typedef enum match_result {
-    RESULT_NO_MATCH = 0,
-    RESULT_SELECTIVE_MATCH = 2,
-    RESULT_EQUAL_MATCH = 4,
-    RESULT_PARTIAL_MATCH = 16,
-    RESULT_NO_LIMIT_MATCH = 32,
-    RESULT_PARTIAL_LIMIT_MATCH = 64,
-} match_result;
+match_t check_rxtree(file_t, seltree*, char *, bool, const char *);
+match_result check_limit(char*, bool, const char *);
 
-match_result check_rxtree(char*,seltree*, rx_rule* *, RESTRICTION_TYPE, char *);
+struct db_line* get_file_attrs(disk_entry *, DB_ATTR_TYPE, DB_ATTR_TYPE, const char *);
+void add_file_to_tree(seltree*, db_line*, int, const database *, disk_entry *, const char*);
 
-struct db_line* get_file_attrs(char*,DB_ATTR_TYPE, struct stat *);
-void add_file_to_tree(seltree*, db_line*, int, const database *, struct stat *);
-
-void print_match(char*, rx_rule*, match_result, RESTRICTION_TYPE);
+void print_match(file_t, match_t);
 #endif /*_GEN_LIST_H_INCLUDED*/
