@@ -1,7 +1,7 @@
 /*
  * AIDE (Advanced Intrusion Detection Environment)
  *
- * Copyright (C) 2019-2022 Hannes von Haugwitz
+ * Copyright (C) 2019-2025 Hannes von Haugwitz
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,7 +27,7 @@
 #include "rx_rule.h"
 #include "util.h"
 
-LOG_LEVEL ast_log_level = LOG_LEVEL_DEBUG;
+LOG_LEVEL ast_log_level = LOG_LEVEL_TRACE;
 
 config_option_t config_options[] = {
     { ACL_NO_SYMLINK_FOLLOW_OPTION,             "acl_no_symlink_follow",        NULL },
@@ -53,7 +53,6 @@ config_option_t config_options[] = {
     { REPORT_URL_OPTION,                        NULL,                           NULL },
     { ROOT_PREFIX_OPTION,                       "root_prefix",                  "Root prefix" },
     { WARN_DEAD_SYMLINKS_OPTION,                NULL,                           NULL },
-    { VERBOSE_OPTION,                           NULL,                           NULL },
     { CONFIG_VERSION,                           "config_version",               "Config version used" },
     { CONFIG_CHECK_WARN_UNRESTRICTED_RULES,     NULL,                           NULL },
     { REPORT_FORMAT_OPTION,                     NULL,                           NULL },
@@ -61,7 +60,7 @@ config_option_t config_options[] = {
     { NUM_WORKERS,                              NULL,                           NULL },
 };
 
-static ast* new_ast_node() {
+static ast* new_ast_node(void) {
     ast* a = checked_malloc(sizeof(ast));
 
     a->linenumber = conf_linenumber;
@@ -79,7 +78,7 @@ ast* new_string_option_statement(config_option option, string_expression* value)
       a->statement._config.option = option;
       a->statement._config.a = NULL;
       a->statement._config.e = value;
-      log_msg(ast_log_level, "ast: new string option statement (%p): option: %d, value: %p", a, option, value);
+      log_msg(ast_log_level, "ast: new string option statement (%p): option: %d, value: %p", (void*) a, option, (void*) value);
       return a;
 }
 
@@ -90,7 +89,7 @@ ast* new_attribute_option_statement(config_option option, attribute_expression*
       a->statement._config.option = option;
       a->statement._config.a = value;
       a->statement._config.e = NULL;
-      log_msg(ast_log_level, "ast: new attribute option statement (%p): option: %d, value: %p", a, option, value);
+      log_msg(ast_log_level, "ast: new attribute option statement (%p): option: %d, value: %p", (void*) a, option, (void*) value);
       return a;
 }
 
@@ -103,7 +102,7 @@ ast* new_include_statement(string_expression* path, string_expression* rx, bool
       a->statement._include.execute = execute;
       a->statement._include.prefix = prefix;
 
-      log_msg(ast_log_level, "ast: new include statement (%p): path: %p, rx: %p, execute: %s, prefix: %p", a, path, rx, btoa(execute), prefix);
+      log_msg(ast_log_level, "ast: new include statement (%p): path: %p, rx: %p, execute: %s, prefix: %p", (void*) a, (void*) path, (void*) rx, btoa(execute), (void*) prefix);
       return a;
 }
 
@@ -113,7 +112,7 @@ ast* new_x_include_setenv_statement(char *variable, string_expression *value) {
       a->type = x_include_setenv_statement_type;
       a->statement._x_include_setenv.variable = variable;
       a->statement._x_include_setenv.value = value;
-      log_msg(ast_log_level, "ast: new x_include_setenv statement (%p): variable: '%s', value: %p", a, variable, value);
+      log_msg(ast_log_level, "ast: new x_include_setenv statement (%p): variable: '%s', value: %p", (void*) a, variable, (void*) value);
       return a;
 }
 
@@ -123,7 +122,7 @@ ast* new_define_statement(char *name, string_expression *value) {
       a->type = define_statement_type;
       a->statement._define.name = name;
       a->statement._define.value = value;
-      log_msg(ast_log_level, "ast: new define statement (%p): name: '%s', value: %p", a, name, value);
+      log_msg(ast_log_level, "ast: new define statement (%p): name: '%s', value: %p", (void*) a, name, (void*) value);
       return a;
 }
 
@@ -132,7 +131,7 @@ ast* new_undefine_statement(char *name) {
 
       a->type = undefine_statement_type;
       a->statement._undefine.name = name;
-      log_msg(ast_log_level, "ast: new undefine statement (%p): name: '%s'", a, name);
+      log_msg(ast_log_level, "ast: new undefine statement (%p): name: '%s'", (void*) a, name);
       return a;
 }
 
@@ -142,27 +141,25 @@ ast* new_group_statement(char* name, attribute_expression* expr) {
       a->type = group_statement_type;
       a->statement._group.name = name;
       a->statement._group.expr = expr;
-      log_msg(ast_log_level, "ast: new group statement (%p): name: '%s', expr: %p", a, name, expr);
+      log_msg(ast_log_level, "ast: new group statement (%p): name: '%s', expr: %p", (void*) a, name, (void*) expr);
       return a;
 }
 
-bool_expression* new_string_bool_expression(bool_operator op, string_expression* expr) {
+bool_expression* new_string_bool_expression(bool_operator op, string_expression* left, string_expression* right) {
     bool_expression* e = checked_malloc(sizeof(bool_expression));
     e->op = op;
-    e->expr = expr;
-    e->left = NULL;
-    e->right = NULL;
-    log_msg(ast_log_level, "ast: new bool expression (%p): op: %d, expr: %p", e, op, expr);
+    e->left._str = left;
+    e->right._str = right;
+    log_msg(ast_log_level, "ast: new string bool expression (%p): op: %d, left: %p, right: %p", (void*) e, op, (void*) left, (void*) right);
     return e;
 }
 
 bool_expression* new_bool_expression(bool_operator op, bool_expression* left, bool_expression* right) {
     bool_expression* e = checked_malloc(sizeof(bool_expression));
     e->op = op;
-    e->expr = NULL;
-    e->left = left;
-    e->right = right;
-    log_msg(ast_log_level, "ast: new bool expression (%p): op: %d, left: %p, right: %p", e, op, left, right);
+    e->left._bool = left;
+    e->right._bool = right;
+    log_msg(ast_log_level, "ast: new bool expression (%p): op: %d, left: %p, right: %p", (void*) e, op, (void*) left, (void*) right);
     return e;
 }
 
@@ -175,7 +172,7 @@ if_condition* new_if_condition(bool_expression* expression) {
 
     c->expression = expression;
 
-    log_msg(ast_log_level, "ast: if condition (%p): expression: %p", c,  expression);
+    log_msg(ast_log_level, "ast: if condition (%p): expression: %p", (void*) c,  (void*) expression);
     return c;
 }
 
@@ -184,15 +181,23 @@ attribute_expression* new_attribute_expression(attribute_operator op, attribute_
     e->op = op;
     e->left = left;
     e->right = right;
-    log_msg(ast_log_level, "ast: new attribute expression (%p): op: %d, left: %p, right: '%s'", e, op, left, right);
+    log_msg(ast_log_level, "ast: new attribute expression (%p): op: %d, left: %p, right: '%s'", (void*) e, op, (void*) left, right);
     return e;
 }
 
-restriction_expression* new_restriction_expression(restriction_expression* left, char* right) {
-    restriction_expression* e = checked_malloc(sizeof(restriction_expression));
+ft_restriction_expression* new_ft_restriction_expression(ft_restriction_expression* left, char* right) {
+    ft_restriction_expression* e = checked_malloc(sizeof(ft_restriction_expression));
     e->right = right;
     e->left = left;
-    log_msg(ast_log_level, "ast: new restriction expression (%p): left: %p, right: '%s'", e, left, right);
+    log_msg(ast_log_level, "ast: new file type restriction expression (%p): left: %p, right: '%s'", (void*) e, (void*) left, right);
+    return e;
+}
+
+restriction_expression* new_restriction_expression(ft_restriction_expression* f_types, char* fs_type) {
+    restriction_expression* e = checked_malloc(sizeof(restriction_expression));
+    e->f_types = f_types;
+    e->fs_type = fs_type;
+    log_msg(ast_log_level, "ast: new restriction expression (%p): f_types: '%p', fs_type: %s", (void*) e, (void*) f_types, (fs_type != NULL) ? fs_type : "(null)");
     return e;
 }
 
@@ -203,7 +208,7 @@ ast* new_if_statement(struct if_condition* condition, struct ast* if_branch, str
       e->statement._if.condition = condition;
       e->statement._if.if_branch = if_branch;
       e->statement._if.else_branch = else_branch;
-      log_msg(ast_log_level, "ast: new if statement (%p): condition: %p, if_branch: %p, else_branch: %p", e, condition, if_branch, else_branch);
+      log_msg(ast_log_level, "ast: new if statement (%p): condition: %p, if_branch: %p, else_branch: %p", (void*) e, (void*) condition, (void*) if_branch, (void*) else_branch);
       return e;
 }
 
@@ -215,7 +220,7 @@ ast* new_rule_statement(AIDE_RULE_TYPE rule_type, string_expression* path, restr
       e->statement._rule.path = path;
       e->statement._rule.restriction = restriction;
       e->statement._rule.attributes = attrs;
-      log_msg(ast_log_level, "ast: new rule statement (%p): type: %s, path: %p, restriction: %p, attributes: %p", e, get_rule_type_long_string(rule_type), path, restriction, attrs);
+      log_msg(ast_log_level, "ast: new rule statement (%p): type: %s, path: %p, restriction: %p, attributes: %p", (void*) e, get_rule_type_long_string(rule_type), (void*) path, (void*) restriction, (void*) attrs);
       return e;
 }
 
@@ -226,7 +231,7 @@ string_expression* new_string(char *str) {
     e->str = str;
     e->left = NULL;
     e->right = NULL;
-    log_msg(ast_log_level, "ast: new string (%p): str: '%s'", e, str);
+    log_msg(ast_log_level, "ast: new string (%p): str: '%s'", (void*) e, str);
     return e;
 }
 string_expression* new_variable(char *name) {
@@ -236,7 +241,7 @@ string_expression* new_variable(char *name) {
     e->str = name;
     e->left = NULL;
     e->right = NULL;
-    log_msg(ast_log_level, "ast: new variable (%p): name: '%s'", e, name);
+    log_msg(ast_log_level, "ast: new variable (%p): name: '%s'", (void*) e, name);
     return e;
 }
 string_expression* new_string_concat(string_expression* left, string_expression* right) {
@@ -245,7 +250,7 @@ string_expression* new_string_concat(string_expression* left, string_expression*
     e->str = NULL;
     e->left = left;
     e->right = right;
-    log_msg(ast_log_level, "ast: new string concat (%p): left: %p, right: %p", e, left, right);
+    log_msg(ast_log_level, "ast: new string concat (%p): left: %p, right: %p", (void*) e, (void*) left, (void*) right);
     return e;
 }
 
@@ -253,7 +258,7 @@ void free_string(char * s) {
     if (s == NULL) {
         return;
     }
-    log_msg(ast_log_level, "ast: free string %p", s);
+    log_msg(ast_log_level, "ast: free string %p", (void*) s);
     free(s);
 }
 
@@ -263,7 +268,7 @@ void free_attribute_expression(attribute_expression *a) {
     }
     free_attribute_expression(a->left);
     free_string(a->right);
-    log_msg(ast_log_level, "ast: free attribute expression %p", a);
+    log_msg(ast_log_level, "ast: free attribute expression %p", (void*) a);
     free(a);
 }
 
@@ -274,7 +279,7 @@ void free_string_expression(string_expression *s) {
     free_string_expression(s->left);
     free_string_expression(s->right);
     free_string(s->str);
-    log_msg(ast_log_level, "ast: free string expression %p", s);
+    log_msg(ast_log_level, "ast: free string expression %p", (void*) s);
     free(s);
 }
 
@@ -282,27 +287,50 @@ void free_bool_expression(bool_expression *b) {
     if (b == NULL) {
         return;
     }
-    free_string_expression(b->expr);
-    free_bool_expression(b->left);
-    free_bool_expression(b->right);
-    log_msg(ast_log_level, "ast: free bool expression %p", b);
+    switch (b->op) {
+        case BOOL_OP_NOT:
+            free_bool_expression(b->left._bool);
+            break;
+        case BOOL_OP_EXISTS:
+        case BOOL_OP_DEFINED:
+        case BOOL_OP_HOSTNAME:
+            free_string_expression(b->left._str);
+            break;
+        case BOOL_OP_VERSION_GE:
+            free_string_expression(b->left._str);
+            free_string_expression(b->right._str);
+            break;
+    }
+    log_msg(ast_log_level, "ast: free bool expression %p", (void*) b);
     free(b);
 }
 
 void free_if_condition(if_condition *c) {
     free_bool_expression(c->expression);
     free_string(c->linebuf);
-    log_msg(ast_log_level, "ast: free if condition %p", c);
+    log_msg(ast_log_level, "ast: free if condition %p", (void*) c);
     free(c);
 }
 
+void free_ft_restriction_expression(ft_restriction_expression *r) {
+    if (r == NULL) {
+        return;
+    }
+    free_ft_restriction_expression(r->left);
+    free_string(r->right);
+    log_msg(ast_log_level, "ast: free file type restriction expression %p", (void*) r);
+    free(r);
+}
+
 void free_restriction_expression(restriction_expression *r) {
     if (r == NULL) {
         return;
     }
-    free_restriction_expression(r->left);
-    free_string(r->right);
-    log_msg(ast_log_level, "ast: free restriction expression %p", r);
+#ifdef HAVE_FSTYPE
+    free_string(r->fs_type);
+#endif
+    free_ft_restriction_expression(r->f_types);
+    log_msg(ast_log_level, "ast: free restriction expression %p", (void*) r);
     free(r);
 }
 
@@ -351,7 +379,7 @@ void deep_free(ast* config_ast) {
         free(node->linebuf);
         ast* to_be_freed = node;
         node = node->next;
-        log_msg(ast_log_level, "ast: free ast node %p (next: %p)", to_be_freed, node);
+        log_msg(ast_log_level, "ast: free ast node %p (next: %p)", (void*) to_be_freed, (void*) node);
         free(to_be_freed);
     }
 }
