@@ -68,22 +68,24 @@ extern int confdebug;
     TIFHOST = 263,                 /* "@@ifhost"  */
     TIF = 264,                     /* "@@if"  */
     TBOOLNOT = 265,                /* "not"  */
-    TBOOLFUNC = 266,               /* "boolean operator or function"  */
-    TELSE = 267,                   /* "@@else"  */
-    TENDIF = 268,                  /* "@@endif"  */
-    TINCLUDE = 269,                /* "@@include"  */
-    TXINCLUDE = 270,               /* "@@x_include"  */
-    TSETENV = 271,                 /* "@@x_include_setenv"  */
-    TGROUP = 272,                  /* "group name"  */
-    TSTRING = 273,                 /* "string"  */
-    TEXPR = 274,                   /* "group"  */
-    TVARIABLE = 275,               /* "variable name"  */
-    TSPACE = 276,                  /* "whitespace"  */
-    TNEWLINE = 277,                /* "new line"  */
-    TSELRXRULE = 278,              /* "regular rule"  */
-    TEQURXRULE = 279,              /* "equals rule"  */
-    TNEGRXRULE = 280,              /* "negative rule"  */
-    CONFIGOPTION = 281             /* "configuration option"  */
+    TBOOLFUNC = 266,               /* "boolean function"  */
+    TBOOLOP = 267,                 /* "boolean operator"  */
+    TELSE = 268,                   /* "@@else"  */
+    TENDIF = 269,                  /* "@@endif"  */
+    TINCLUDE = 270,                /* "@@include"  */
+    TXINCLUDE = 271,               /* "@@x_include"  */
+    TSETENV = 272,                 /* "@@x_include_setenv"  */
+    TGROUP = 273,                  /* "group name"  */
+    TSTRING = 274,                 /* "string"  */
+    TEXPR = 275,                   /* "group"  */
+    TVARIABLE = 276,               /* "variable name"  */
+    TSPACE = 277,                  /* "whitespace"  */
+    TNEWLINE = 278,                /* "new line"  */
+    TSELRXRULE = 279,              /* "regular rule"  */
+    TEQURXRULE = 280,              /* "equals rule"  */
+    TRECNEGRXRULE = 281,           /* "recursive negative rule"  */
+    TNONRECNEGRXRULE = 282,        /* "non-recursive negative rule"  */
+    CONFIGOPTION = 283             /* "configuration option"  */
   };
   typedef enum yytokentype yytoken_kind_t;
 #endif
@@ -101,21 +103,23 @@ extern int confdebug;
 #define TIF 264
 #define TBOOLNOT 265
 #define TBOOLFUNC 266
-#define TELSE 267
-#define TENDIF 268
-#define TINCLUDE 269
-#define TXINCLUDE 270
-#define TSETENV 271
-#define TGROUP 272
-#define TSTRING 273
-#define TEXPR 274
-#define TVARIABLE 275
-#define TSPACE 276
-#define TNEWLINE 277
-#define TSELRXRULE 278
-#define TEQURXRULE 279
-#define TNEGRXRULE 280
-#define CONFIGOPTION 281
+#define TBOOLOP 267
+#define TELSE 268
+#define TENDIF 269
+#define TINCLUDE 270
+#define TXINCLUDE 271
+#define TSETENV 272
+#define TGROUP 273
+#define TSTRING 274
+#define TEXPR 275
+#define TVARIABLE 276
+#define TSPACE 277
+#define TNEWLINE 278
+#define TSELRXRULE 279
+#define TEQURXRULE 280
+#define TRECNEGRXRULE 281
+#define TNONRECNEGRXRULE 282
+#define CONFIGOPTION 283
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
@@ -135,9 +139,10 @@ union YYSTYPE
   bool_expression* bool_expr;
   attribute_expression* attr_expr;
   restriction_expression* rs_expr;
+  ft_restriction_expression* ft_rs_expr;
   string_expression* string_expr;
 
-#line 141 "src/conf_yacc.h"
+#line 146 "src/conf_yacc.h"
 
 };
 typedef union YYSTYPE YYSTYPE;
